summaryrefslogtreecommitdiff
path: root/src/helpers
diff options
context:
space:
mode:
authorJohn Estabrook <jestabro@vyos.io>2020-07-22 14:25:58 -0500
committerGitHub <noreply@github.com>2020-07-22 14:25:58 -0500
commitda65aa2290e54f47dcc9c527723557fdbe2cb892 (patch)
treeea8848624d98e4b1693b45c0ea3021f00d646d80 /src/helpers
parent632b3693097f665464d3072da138eb9a7e370309 (diff)
parent280044183e086c1ef1fbe9e8a7291f738bb7e504 (diff)
downloadvyos-1x-da65aa2290e54f47dcc9c527723557fdbe2cb892.tar.gz
vyos-1x-da65aa2290e54f47dcc9c527723557fdbe2cb892.zip
Merge pull request #499 from jestabro/config_source
T2707: allow alternative initialization data for config config: T2707: use ConfigSource and refactor Config methods load-config: subclass ConfigSourceSession instead of Config http-api: remove unneeded check for VyOSError config: T2707: add ConfigSource classes for alternative init data
Diffstat (limited to 'src/helpers')
-rwxr-xr-xsrc/helpers/vyos-load-config.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/helpers/vyos-load-config.py b/src/helpers/vyos-load-config.py
index a9fa15778..c2da1bb11 100755
--- a/src/helpers/vyos-load-config.py
+++ b/src/helpers/vyos-load-config.py
@@ -27,12 +27,12 @@ import sys
import tempfile
import vyos.defaults
import vyos.remote
-from vyos.config import Config, VyOSError
+from vyos.configsource import ConfigSourceSession, VyOSError
from vyos.migrator import Migrator, VirtualMigrator, MigratorError
-class LoadConfig(Config):
+class LoadConfig(ConfigSourceSession):
"""A subclass for calling 'loadFile'.
This does not belong in config.py, and only has a single caller.
"""
def load_config(self, path):
return self._run(['/bin/cli-shell-api','loadFile',path])
@@ -27,12 +27,12 @@ import sys
"""A subclass for calling 'loadFile'.
- This does not belong in config.py, and only has a single caller.
+ This does not belong in configsource.py, and only has a single caller.
"""
def load_config(self, path):